# Play

## What is it?
Play is a video player for the terminal. You can play videos from your computer running Play.

## How to install?
Play is a python package. You can install it with the following command:

    $ pip install play-video

## How to use it?
Play uses a command line interface:

    $ play <video> <video> <video> ...

Example:

    $ play ~/Videos/video.mp4 ~/Videos/video2.mp4

The video https://www.youtube.com/watch?v=u_jJkkxeE30 will be reproduced as:

![Screen Gif](assets/screen-gif.gif)